==> seantis.people-0.2.tar.gz: seantis.people-0.2/seantis/people/tests/test_membership.py <==
from datetime import date
from plone import api
from zope.interface import Invalid

from seantis.people.interfaces import IMembership, IPerson
from seantis.people.content import Membership
from seantis.people import tests


class TestMembership(tests.IntegrationTestCase):

    def test_membership_creation(self):
        with self.user('admin'):
            ms = api.content.create(
                id='test',
                type='seantis.people.membership',
                container=self.new_temporary_folder()
            )

        self.assertIs(type(ms.aq_base), Membership)

    def test_membership_range_validation(self):
        with self.user('admin'):
            ms = api.content.create(
                id='test',
                type='seantis.people.membership',
                container=self.new_temporary_folder()
            )

        ms.start, ms.end = None, None
        IMembership.validateInvariants(ms)

        ms.start, ms.end = date(2012, 1, 1), None
        IMembership.validateInvariants(ms)

        ms.start, ms.end = None, date(2012, 1, 1)
        IMembership.validateInvariants(ms)

        ms.start, ms.end = date(2012, 1, 1), date(2012, 1, 2)
        IMembership.validateInvariants(ms)

        ms.start, ms.end = date(2012, 1, 1), date(2012, 1, 1)
        IMembership.validateInvariants(ms)

        ms.start, ms.end = date(2012, 1, 2), date(2012, 1, 1)
        self.assertRaises(Invalid, IMembership.validateInvariants, ms)

    def test_membership_person_relation(self):
        person_type = self.new_temporary_type(
            behaviors=[IPerson.__identifier__]
        )

        with self.user('admin'):
            organization = self.new_temporary_folder('S.H.I.E.L.D')

            nick_fury = IPerson(api.content.create(
                title='Nick Fury',
                type=person_type.id,
                container=self.new_temporary_folder()
            ))

            api.content.create(
                title='Leader',
                type='seantis.people.membership',
                container=organization,
                person=nick_fury
            )

        self.assertEqual(len(nick_fury.memberships()), 1)

        with self.user('admin'):
            api.content.create(
                title='Leutenant',
                type='seantis.people.membership',
                container=organization,
                person=nick_fury
            )

        self.assertEqual(len(nick_fury.memberships()), 2)

    def test_membership_by_organization(self):
        person_type = self.new_temporary_type(
            behaviors=[IPerson.__identifier__]
        )

        with self.user('admin'):
            uno = self.new_temporary_folder('UNO')
            nato = self.new_temporary_folder('NATO')

            john = IPerson(api.content.create(
                title='John Doe',
                type=person_type.id,
                container=self.new_temporary_folder()
            ))

            api.content.create(
                title='Janitor',
                type='seantis.people.membership',
                container=uno,
                person=john
            )

            api.content.create(
                title='Janitor',
                type='seantis.people.membership',
                container=nato,
                person=john
            )

        self.assertEqual(len(john.memberships()), 2)
        self.assertEqual(len(john.memberships_by_organization()), 2)
        self.assertEqual(len(john.memberships_by_organization(['UNO'])), 1)
        self.assertEqual(len(john.memberships_by_organization(['NATO'])), 1)
        self.assertEqual(len(john.memberships_by_organization(['ASDF'])), 0)

==> seantis.people-0.14.tar.gz: seantis.people-0.14/seantis/people/tests/test_membership.py <==
from datetime import date
from plone import api
from plone.uuid.interfaces import IUUID
from zope.interface import Invalid

from seantis.people.interfaces import IMembership, IPerson
from seantis.people.content import Membership
from seantis.people import tests


class TestMembership(tests.IntegrationTestCase):

    def test_membership_creation(self):
        with self.user('admin'):
            ms = api.content.create(
                id='test',
                type='seantis.people.membership',
                container=self.new_temporary_folder()
            )

        self.assertIs(type(ms.aq_base), Membership)

    def test_membership_range_validation(self):
        with self.user('admin'):
            ms = api.content.create(
                id='test',
                type='seantis.people.membership',
                container=self.new_temporary_folder()
            )

        ms.start, ms.end = None, None
        IMembership.validateInvariants(ms)

        ms.start, ms.end = date(2012, 1, 1), None
        IMembership.validateInvariants(ms)

        ms.start, ms.end = None, date(2012, 1, 1)
        IMembership.validateInvariants(ms)

        ms.start, ms.end = date(2012, 1, 1), date(2012, 1, 2)
        IMembership.validateInvariants(ms)

        ms.start, ms.end = date(2012, 1, 1), date(2012, 1, 1)
        IMembership.validateInvariants(ms)

        ms.start, ms.end = date(2012, 1, 2), date(2012, 1, 1)
        self.assertRaises(Invalid, IMembership.validateInvariants, ms)

    def test_membership_person_relation(self):
        person_type = self.new_temporary_type(
            behaviors=[IPerson.__identifier__]
        )

        with self.user('admin'):
            organization = self.new_temporary_folder('S.H.I.E.L.D')

            nick_fury = api.content.create(
                title='Nick Fury',
                type=person_type.id,
                container=self.new_temporary_folder()
            )

            tony_stark = api.content.create(
                title='Tony Stark',
                type=person_type.id,
                container=self.new_temporary_folder()
            )

            api.content.create(
                title='Director',
                type='seantis.people.membership',
                container=organization,
                person=nick_fury
            )

            api.content.create(
                title='Head',
                type='seantis.people.membership',
                container=organization,
                person=tony_stark
            )

        memberships = IPerson(nick_fury).memberships()

        org = IUUID(organization)

        self.assertEqual(len(memberships), 1)
        self.assertEqual(memberships.keys(), [org])
        self.assertEqual(len(memberships[org]), 1)
        self.assertEqual(memberships[org][0].Title, 'Director')

        with self.user('admin'):
            api.content.create(
                title='Leutenant',
                type='seantis.people.membership',
                container=organization,
                person=nick_fury
            )

        memberships = IPerson(nick_fury).memberships()

        self.assertEqual(len(memberships), 1)
        self.assertEqual(memberships.keys(), [org])
        self.assertEqual(len(memberships[org]), 2)
        self.assertEqual(memberships[org][0].Title, 'Director')
        self.assertEqual(memberships[org][1].Title, 'Leutenant')
